@@ -1,7 +1,6 @@
 import copy
 import os
 from argparse import Namespace
-from pathlib import Path
 from typing import Dict, List, Optional, Tuple, Union
 
 from jina import __default_executor__
@@ -97,7 +96,7 @@ class DockerComposeConfig:
                 'expose': ports,
                 'ports': [f'{_port}:{_port}' for _port in ports],
                 'healthcheck': {
-                    'test': f'python -m jina.resources.health_check.gateway localhost:{cargs.port} {protocol}',
+                    'test': f'jina ping gateway {protocol}://127.0.0.1:{cargs.port}',
                     'interval': '2s',
                 },
                 'environment': envs,
@@ -166,7 +165,7 @@ class DockerComposeConfig:
                     'entrypoint': ['jina'],
                     'command': container_args,
                     'healthcheck': {
-                        'test': f'python -m jina.resources.health_check.pod localhost:{cargs.port}',
+                        'test': f'jina ping executor 127.0.0.1:{cargs.port}',
                         'interval': '2s',
                     },
                     'environment': [
@@ -174,6 +173,26 @@ class DockerComposeConfig:
                     ],
                 }
 
+                if cargs.gpus:
+                    try:
+                        count = int(cargs.gpus)
+                    except ValueError:
+                        count = cargs.gpus
+
+                    config['deploy'] = {
+                        'resources': {
+                            'reservations': {
+                                'devices': [
+                                    {
+                                        'driver': 'nvidia',
+                                        'count': count,
+                                        'capabilities': ['gpu'],
+                                    }
+                                ]
+                            }
+                        }
+                    }
+
                 if cargs.monitoring:
                     config['expose'] = [cargs.port_monitoring]
                     config['ports'] = [
