@@ -1,19 +1,17 @@
 import argparse
-import json
-from typing import TYPE_CHECKING, Any, AsyncIterator, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, AsyncIterator, Dict, List, Optional, Union
 
 from jina.clients.request import request_generator
 from jina.enums import DataInputType, WebsocketSubProtocols
 from jina.excepts import InternalNetworkError
+from jina.helper import get_full_version
 from jina.importer import ImportExtensions
 from jina.logging.logger import JinaLogger
 from jina.types.request.data import DataRequest
+from jina.types.request.status import StatusMessage
 
 if TYPE_CHECKING:
-    from prometheus_client import CollectorRegistry
-
-    from jina.serve.networking import GrpcConnectionPool
-    from jina.serve.runtimes.gateway.graph.topology_graph import TopologyGraph
+    from jina.serve.streamer import GatewayStreamer
 
 
 def _fits_ws_close_msg(msg: str):
@@ -24,20 +22,14 @@ def _fits_ws_close_msg(msg: str):
 
 
 def get_fastapi_app(
-    args: 'argparse.Namespace',
-    topology_graph: 'TopologyGraph',
-    connection_pool: 'GrpcConnectionPool',
+    streamer: 'GatewayStreamer',
     logger: 'JinaLogger',
-    metrics_registry: Optional['CollectorRegistry'] = None,
 ):
     """
     Get the app from FastAPI as the Websocket interface.
 
-    :param args: passed arguments.
-    :param topology_graph: topology graph that manages the logic of sending to the proper executors.
-    :param connection_pool: Connection Pool to handle multiple replicas and sending to different of them
+    :param streamer: gateway streamer object.
     :param logger: Jina logger.
-    :param metrics_registry: optional metrics registry for prometheus used if we need to expose metrics from the executor or from the data request handler
     :return: fastapi app
     """
 
@@ -104,7 +96,9 @@ def get_fastapi_app(
             except WebSocketDisconnect:
                 pass
 
-        async def send(self, websocket: WebSocket, data: DataRequest) -> None:
+        async def send(
+            self, websocket: WebSocket, data: Union[DataRequest, StatusMessage]
+        ) -> None:
             subprotocol = self.protocol_dict[self.get_client(websocket)]
             if subprotocol == WebsocketSubProtocols.JSON:
                 return await websocket.send_json(data.to_dict(), mode='text')
@@ -115,24 +109,40 @@ def get_fastapi_app(
 
     app = FastAPI()
 
-    from jina.serve.runtimes.gateway.request_handling import RequestHandler
-    from jina.serve.stream import RequestStreamer
-
-    request_handler = RequestHandler(metrics_registry, args.name)
-
-    streamer = RequestStreamer(
-        args=args,
-        request_handler=request_handler.handle_request(
-            graph=topology_graph, connection_pool=connection_pool
-        ),
-        result_handler=request_handler.handle_result(),
+    @app.get(
+        path='/',
+        summary='Get the health of Jina service',
     )
+    async def _health():
+        """
+        Get the health of this Jina service.
+        .. # noqa: DAR201
 
-    streamer.Call = streamer.stream
+        """
+        return {}
+
+    @app.get(
+        path='/status',
+        summary='Get the status of Jina service',
+    )
+    async def _status():
+        """
+        Get the status of this Jina service.
+
+        This is equivalent to running `jina -vf` from command line.
+
+        .. # noqa: DAR201
+        """
+        version, env_info = get_full_version()
+        for k, v in version.items():
+            version[k] = str(v)
+        for k, v in env_info.items():
+            env_info[k] = str(v)
+        return {'jina': version, 'envs': env_info}
 
     @app.on_event('shutdown')
     async def _shutdown():
-        await connection_pool.close()
+        await streamer.close()
 
     @app.websocket('/')
     async def websocket_endpoint(
@@ -166,6 +176,97 @@ def get_fastapi_app(
         try:
             async for msg in streamer.stream(request_iterator=req_iter()):
                 await manager.send(websocket, msg)
+        except InternalNetworkError as err:
+            import grpc
+
+            manager.disconnect(websocket)
+            fallback_msg = (
+                f'Connection to deployment at {err.dest_addr} timed out. You can adjust `timeout_send` attribute.'
+                if err.code() == grpc.StatusCode.DEADLINE_EXCEEDED
+                else f'Network error while connecting to deployment at {err.dest_addr}. It may be down.'
+            )
+            msg = (
+                err.details()
+                if _fits_ws_close_msg(
+                    err.details()
+                )  # some messages are too long for ws closing message
+                else fallback_msg
+            )
+            await websocket.close(code=status.WS_1011_INTERNAL_ERROR, reason=msg)
+        except WebSocketDisconnect:
+            logger.info('Client successfully disconnected from server')
+            manager.disconnect(websocket)
+
+    async def _get_singleton_result(request_iterator) -> Dict:
+        """
+        Streams results from AsyncPrefetchCall as a dict
+
+        :param request_iterator: request iterator, with length of 1
+        :return: the first result from the request iterator
+        """
+        async for k in streamer.stream(request_iterator=request_iterator):
+            request_dict = k.to_dict()
+            return request_dict
+
+    from docarray import DocumentArray
+
+    from jina.proto import jina_pb2
+    from jina.serve.executors import __dry_run_endpoint__
+    from jina.serve.runtimes.gateway.http.models import PROTO_TO_PYDANTIC_MODELS
+
+    @app.get(
+        path='/dry_run',
+        summary='Get the readiness of Jina Flow service, sends an empty DocumentArray to the complete Flow to '
+        'validate connectivity',
+        response_model=PROTO_TO_PYDANTIC_MODELS.StatusProto,
+    )
+    async def _dry_run_http():
+        """
+        Get the health of the complete Flow service.
+        .. # noqa: DAR201
+
+        """
+
+        da = DocumentArray()
+
+        try:
+            _ = await _get_singleton_result(
+                request_generator(
+                    exec_endpoint=__dry_run_endpoint__,
+                    data=da,
+                    data_type=DataInputType.DOCUMENT,
+                )
+            )
+            status_message = StatusMessage()
+            status_message.set_code(jina_pb2.StatusProto.SUCCESS)
+            return status_message.to_dict()
+        except Exception as ex:
+            status_message = StatusMessage()
+            status_message.set_exception(ex)
+            return status_message.to_dict(use_integers_for_enums=True)
+
+    @app.websocket('/dry_run')
+    async def websocket_endpoint(
+        websocket: WebSocket, response: Response
+    ):  # 'response' is a FastAPI response, not a Jina response
+        from jina.proto import jina_pb2
+        from jina.serve.executors import __dry_run_endpoint__
+
+        await manager.connect(websocket)
+
+        da = DocumentArray()
+        try:
+            async for _ in streamer.stream(
+                request_iterator=request_generator(
+                    exec_endpoint=__dry_run_endpoint__,
+                    data=da,
+                    data_type=DataInputType.DOCUMENT,
+                )
+            ):
+                pass
+            status_message = StatusMessage()
+            status_message.set_code(jina_pb2.StatusProto.SUCCESS)
+            await manager.send(websocket, status_message)
         except InternalNetworkError as err:
             manager.disconnect(websocket)
             msg = (
@@ -177,5 +278,10 @@ def get_fastapi_app(
         except WebSocketDisconnect:
             logger.info('Client successfully disconnected from server')
             manager.disconnect(websocket)
+        except Exception as ex:
+            manager.disconnect(websocket)
+            status_message = StatusMessage()
+            status_message.set_exception(ex)
+            await manager.send(websocket, status_message)
 
     return app
